summaryrefslogtreecommitdiffstats
path: root/src/latin1literal.h
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2013-06-29 12:56:53 +0200
committerSlávek Banko <slavek.banko@axis.cz>2013-07-04 03:11:35 +0200
commit5f5e7c5455d52826b0bd50f64fcffb7695ce970d (patch)
treec8ee8792d3fb139365abbf70c2255f1e69d2aa34 /src/latin1literal.h
parent251c9a439759c830d34c70683d0fc9454d703010 (diff)
downloadkbibtex-5f5e7c5455d52826b0bd50f64fcffb7695ce970d.tar.gz
kbibtex-5f5e7c5455d52826b0bd50f64fcffb7695ce970d.zip
Initial TQt conversion
Diffstat (limited to 'src/latin1literal.h')
-rw-r--r--src/latin1literal.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/latin1literal.h b/src/latin1literal.h
index 97c4cfc..1abcf6d 100644
--- a/src/latin1literal.h
+++ b/src/latin1literal.h
@@ -27,18 +27,18 @@
#ifndef LATIN1LITERAL_H
#define LATIN1LITERAL_H
-#include <qstring.h>
+#include <ntqstring.h>
namespace KBibTeX {
/**
* A class for explicit marking of string literals encoded in the ISO
* 8859-1 character set. Allows for efficient, still (in terms of the
* chosen encoding) safe comparison with QString instances. To be used
* like this:
*
* \code
- * QString s = .....
+ * TQString s = .....
* if (s == Latin1Literal("o")) { ..... }
* \endcode
*
@@ -61,8 +61,8 @@ public:
} // end namespace
inline
-bool operator==(const QString& s1, const KBibTeX::Latin1LiteralInternal& s2) {
- const QChar* uc = s1.unicode();
+bool operator==(const TQString& s1, const KBibTeX::Latin1LiteralInternal& s2) {
+ const TQChar* uc = s1.unicode();
const char* c = s2.str;
if(!c || !uc) {
return (!c && !uc);
@@ -82,17 +82,17 @@ bool operator==(const QString& s1, const KBibTeX::Latin1LiteralInternal& s2) {
}
inline
-bool operator!=(const QString& s1, const KBibTeX::Latin1LiteralInternal& s2) {
+bool operator!=(const TQString& s1, const KBibTeX::Latin1LiteralInternal& s2) {
return !(s1 == s2);
}
inline
-bool operator==(const KBibTeX::Latin1LiteralInternal& s1, const QString& s2) {
+bool operator==(const KBibTeX::Latin1LiteralInternal& s1, const TQString& s2) {
return s2 == s1;
}
inline
-bool operator!=(const KBibTeX::Latin1LiteralInternal& s1, const QString& s2) {
+bool operator!=(const KBibTeX::Latin1LiteralInternal& s1, const TQString& s2) {
return !(s2 == s1);
}
@@ -27,18 +27,18 @@
* A class for explicit marking of string literals encoded in the ISO
* 8859-1 character set. Allows for efficient, still (in terms of the
- * chosen encoding) safe comparison with QString instances. To be used
+ * chosen encoding) safe comparison with TQString instances. To be used
* like this:
*